@@ -196,6 +196,13 @@ class FileUtils:
         file.write(contents)
         file.close()
 
+    @classmethod
+    def prepend_to_file(cls, file, content):
+        with open(file, 'r+') as f:
+            content = f.read()
+            f.seek(0, 0)
+            f.write(content)
+
     @classmethod
     def append_data_to_file(cls, path, data):
         dirname = os.path.dirname(path)
